==> Pyrogram-1.0.2-py3-none-any.whl: pyrogram/raw/base/input_privacy_key.py <==
#  Pyrogram - Telegram MTProto API Client Library for Python
#  Copyright (C) 2017-2020 Dan <https://github.com/delivrance>
#
#  This file is part of Pyrogram.
#
#  Pyrogram is free software: you can redistribute it and/or modify
#  it under the terms of the GNU Lesser General Public License as published
#  by the Free Software Foundation, either version 3 of the License, or
#  (at your option) any later version.
#
#  Pyrogram is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU Lesser General Public License for more details.
#
#  You should have received a copy of the GNU Lesser General Public License
#  along with Pyrogram.  If not, see <http://www.gnu.org/licenses/>.

# # # # # # # # # # # # # # # # # # # # # # # #
#               !!! WARNING !!!               #
#          This is a generated file!          #
# All changes made in this file will be lost! #
# # # # # # # # # # # # # # # # # # # # # # # #

from typing import Union
from pyrogram import raw
from pyrogram.raw.core import TLObject

InputPrivacyKey = Union[raw.types.InputPrivacyKeyAddedByPhone, raw.types.InputPrivacyKeyChatInvite, raw.types.InputPrivacyKeyForwards, raw.types.InputPrivacyKeyPhoneCall, raw.types.InputPrivacyKeyPhoneNumber, raw.types.InputPrivacyKeyPhoneP2P, raw.types.InputPrivacyKeyProfilePhoto, raw.types.InputPrivacyKeyStatusTimestamp]


# noinspection PyRedeclaration
class InputPrivacyKey(TLObject):  # type: ignore
    """This base type has 8 constructors available.

    Constructors:
        .. hlist::
            :columns: 2

            - :obj:`InputPrivacyKeyAddedByPhone <pyrogram.raw.types.InputPrivacyKeyAddedByPhone>`
            - :obj:`InputPrivacyKeyChatInvite <pyrogram.raw.types.InputPrivacyKeyChatInvite>`
            - :obj:`InputPrivacyKeyForwards <pyrogram.raw.types.InputPrivacyKeyForwards>`
            - :obj:`InputPrivacyKeyPhoneCall <pyrogram.raw.types.InputPrivacyKeyPhoneCall>`
            - :obj:`InputPrivacyKeyPhoneNumber <pyrogram.raw.types.InputPrivacyKeyPhoneNumber>`
            - :obj:`InputPrivacyKeyPhoneP2P <pyrogram.raw.types.InputPrivacyKeyPhoneP2P>`
            - :obj:`InputPrivacyKeyProfilePhoto <pyrogram.raw.types.InputPrivacyKeyProfilePhoto>`
            - :obj:`InputPrivacyKeyStatusTimestamp <pyrogram.raw.types.InputPrivacyKeyStatusTimestamp>`
    """

    QUALNAME = "pyrogram.raw.base.InputPrivacyKey"

==> Pyrogram-1.0.4-py3-none-any.whl: pyrogram/raw/base/input_privacy_key.py <==
#  Pyrogram - Telegram MTProto API Client Library for Python
#  Copyright (C) 2017-2020 Dan <https://github.com/delivrance>
#
#  This file is part of Pyrogram.
#
#  Pyrogram is free software: you can redistribute it and/or modify
#  it under the terms of the GNU Lesser General Public License as published
#  by the Free Software Foundation, either version 3 of the License, or
#  (at your option) any later version.
#
#  Pyrogram is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU Lesser General Public License for more details.
#
#  You should have received a copy of the GNU Lesser General Public License
#  along with Pyrogram.  If not, see <http://www.gnu.org/licenses/>.

# # # # # # # # # # # # # # # # # # # # # # # #
#               !!! WARNING !!!               #
#          This is a generated file!          #
# All changes made in this file will be lost! #
# # # # # # # # # # # # # # # # # # # # # # # #

from typing import Union
from pyrogram import raw
from pyrogram.raw.core import TLObject

InputPrivacyKey = Union[raw.types.InputPrivacyKeyAddedByPhone, raw.types.InputPrivacyKeyChatInvite, raw.types.InputPrivacyKeyForwards, raw.types.InputPrivacyKeyPhoneCall, raw.types.InputPrivacyKeyPhoneNumber, raw.types.InputPrivacyKeyPhoneP2P, raw.types.InputPrivacyKeyProfilePhoto, raw.types.InputPrivacyKeyStatusTimestamp]


# noinspection PyRedeclaration
class InputPrivacyKey:  # type: ignore
    """This base type has 8 constructors available.

    Constructors:
        .. hlist::
            :columns: 2

            - :obj:`InputPrivacyKeyAddedByPhone <pyrogram.raw.types.InputPrivacyKeyAddedByPhone>`
            - :obj:`InputPrivacyKeyChatInvite <pyrogram.raw.types.InputPrivacyKeyChatInvite>`
            - :obj:`InputPrivacyKeyForwards <pyrogram.raw.types.InputPrivacyKeyForwards>`
            - :obj:`InputPrivacyKeyPhoneCall <pyrogram.raw.types.InputPrivacyKeyPhoneCall>`
            - :obj:`InputPrivacyKeyPhoneNumber <pyrogram.raw.types.InputPrivacyKeyPhoneNumber>`
            - :obj:`InputPrivacyKeyPhoneP2P <pyrogram.raw.types.InputPrivacyKeyPhoneP2P>`
            - :obj:`InputPrivacyKeyProfilePhoto <pyrogram.raw.types.InputPrivacyKeyProfilePhoto>`
            - :obj:`InputPrivacyKeyStatusTimestamp <pyrogram.raw.types.InputPrivacyKeyStatusTimestamp>`
    """

    QUALNAME = "pyrogram.raw.base.InputPrivacyKey"
